==> kubernetes-model-apiextensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CustomResourceDefinitionStatusBuilder extends CustomResourceDefinitionStatusFluentImpl<CustomResourceDefinitionStatusBuilder> implements VisitableBuilder<CustomResourceDefinitionStatus,CustomResourceDefinitionStatusBuilder>{
  public CustomResourceDefinitionStatusBuilder() {
    this(false);
  }
  public CustomResourceDefinitionStatusBuilder(Boolean validationEnabled) {
    this(new CustomResourceDefinitionStatus(), validationEnabled);
  }
  public CustomResourceDefinitionStatusBuilder(CustomResourceDefinitionStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceDefinitionStatusBuilder(CustomResourceDefinitionStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CustomResourceDefinitionStatus(), validationEnabled);
  }
  public CustomResourceDefinitionStatusBuilder(CustomResourceDefinitionStatusFluent<?> fluent,CustomResourceDefinitionStatus instance) {
    this(fluent, instance, false);
  }
  public CustomResourceDefinitionStatusBuilder(CustomResourceDefinitionStatusFluent<?> fluent,CustomResourceDefinitionStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAcceptedNames(instance.getAcceptedNames());
      fluent.withConditions(instance.getConditions());
      fluent.withStoredVersions(instance.getStoredVersions());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceDefinitionStatusBuilder(CustomResourceDefinitionStatus instance) {
    this(instance,false);
  }
  public CustomResourceDefinitionStatusBuilder(CustomResourceDefinitionStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAcceptedNames(instance.getAcceptedNames());
      this.withConditions(instance.getConditions());
      this.withStoredVersions(instance.getStoredVersions());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  CustomResourceDefinitionStatusFluent<?> fluent;
  Boolean validationEnabled;
  public CustomResourceDefinitionStatus build() {
    CustomResourceDefinitionStatus buildable = new CustomResourceDefinitionStatus(fluent.getAcceptedNames(),fluent.getConditions(),fluent.getStoredVersions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-apiextensions-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CustomResourceDefinitionStatusBuilder extends CustomResourceDefinitionStatusFluent<CustomResourceDefinitionStatusBuilder> implements VisitableBuilder<CustomResourceDefinitionStatus,CustomResourceDefinitionStatusBuilder>{
  public CustomResourceDefinitionStatusBuilder() {
    this(false);
  }
  public CustomResourceDefinitionStatusBuilder(Boolean validationEnabled) {
    this(new CustomResourceDefinitionStatus(), validationEnabled);
  }
  public CustomResourceDefinitionStatusBuilder(CustomResourceDefinitionStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceDefinitionStatusBuilder(CustomResourceDefinitionStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CustomResourceDefinitionStatus(), validationEnabled);
  }
  public CustomResourceDefinitionStatusBuilder(CustomResourceDefinitionStatusFluent<?> fluent,CustomResourceDefinitionStatus instance) {
    this(fluent, instance, false);
  }
  public CustomResourceDefinitionStatusBuilder(CustomResourceDefinitionStatusFluent<?> fluent,CustomResourceDefinitionStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new CustomResourceDefinitionStatus());

    if (instance != null) {
      fluent.withAcceptedNames(instance.getAcceptedNames());
      fluent.withConditions(instance.getConditions());
      fluent.withStoredVersions(instance.getStoredVersions());
      fluent.withAcceptedNames(instance.getAcceptedNames());
      fluent.withConditions(instance.getConditions());
      fluent.withStoredVersions(instance.getStoredVersions());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceDefinitionStatusBuilder(CustomResourceDefinitionStatus instance) {
    this(instance,false);
  }
  public CustomResourceDefinitionStatusBuilder(CustomResourceDefinitionStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new CustomResourceDefinitionStatus());

    if (instance != null) {
      this.withAcceptedNames(instance.getAcceptedNames());
      this.withConditions(instance.getConditions());
      this.withStoredVersions(instance.getStoredVersions());
      this.withAcceptedNames(instance.getAcceptedNames());
      this.withConditions(instance.getConditions());
      this.withStoredVersions(instance.getStoredVersions());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  CustomResourceDefinitionStatusFluent<?> fluent;
  Boolean validationEnabled;
  public CustomResourceDefinitionStatus build() {
    CustomResourceDefinitionStatus buildable = new CustomResourceDefinitionStatus(fluent.buildAcceptedNames(),fluent.buildConditions(),fluent.getStoredVersions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
